@@ -17,10 +17,16 @@ def make_ntuples(trex_config, sx_requests, output_parquet_list):
     Path(trex_config.get_job_block('NtuplePath')).mkdir(parents=True, exist_ok=True)
 
     # ROOT file per SAMPLE
+    sam_old = ""
     for (request, output) in zip(sx_requests, output_parquet_list):
         # output_file_name = trex_config.get_job_block('Job') + "/Data/" + request['Sample'] + ".root"
         output_file_name = trex_config.get_job_block('NtuplePath') + "/" + request['Sample'] + ".root"
-        print(f"ntupleName: {request['ntupleName']}")
+        
+        sam = request['Sample']
+        if sam is not sam_old:
+            print(f"  Sample: {sam}")
+            sam_old = sam
+        print(f"    TTree: {request['ntupleName']}")
 
         if request['ntupleName'] != 'nominal':
             output_file = TFile.Open(output_file_name, 'UPDATE')
@@ -29,5 +35,4 @@ def make_ntuples(trex_config, sx_requests, output_parquet_list):
         else:
             parquet_to_root(output, output_file_name, request['ntupleName'], verbose=False)
 
-    # print(f"ROOT ntuples are delivered under {trex_config.get_job_block('Job')}/Data/")
-    print(f"ROOT ntuples are delivered under {trex_config.get_job_block('NtuplePath')}")
+    return trex_config.get_job_block('NtuplePath')
\ No newline at end of file
